@@ -2,5 +2,5 @@
 scripts/extract_strings_ki18n.py `find templates -name \*.html` >> html.cpp
 $EXTRACTRC *.kcfg *.ui >> rc.cpp
 $XGETTEXT rc.cpp html.cpp src/*.cpp src/*.h -o $podir/libkcalutils5.pot
-rm -f rc.cpp html.cpp scripts/grantlee_strings_extractor.pyc
+rm -f rc.cpp html.cpp
 
