@@ -35,7 +35,6 @@ using namespace KCalCore;
 #include <QtCore/QMap>
 #include <QtCore/QTextStream>
 #include <QApplication>
-#include <KLocale>
 #include <QLocale>
 
 using namespace KCalUtils;
@@ -43,10 +42,10 @@ using namespace KCalUtils;
 static QString cleanChars(const QString &txt);
 
 //@cond PRIVATE
-class KCalUtils::HtmlExport::Private
+class KCalUtils::HtmlExportPrivate
 {
 public:
-    Private(MemoryCalendar *calendar, HTMLExportSettings *settings)
+    HtmlExportPrivate(MemoryCalendar *calendar, HTMLExportSettings *settings)
         : mCalendar(calendar), mSettings(settings)
     {}
 
@@ -57,7 +56,7 @@ public:
 //@endcond
 
 HtmlExport::HtmlExport(MemoryCalendar *calendar, HTMLExportSettings *settings)
-    : d(new Private(calendar, settings))
+    : d(new HtmlExportPrivate(calendar, settings))
 {
 }
 
@@ -173,8 +172,8 @@ void HtmlExport::createMonthView(QTextStream *ts)
     while (start < toDate()) {
         // Write header
         QDate hDate(start.year(), start.month(), 1);
-        QString hMon = hDate.toString(QLatin1String("MMMM"));
-        QString hYear = hDate.toString(QLatin1String("yyyy"));
+        QString hMon = hDate.toString(QStringLiteral("MMMM"));
+        QString hYear = hDate.toString(QStringLiteral("yyyy"));
         *ts << "<h2>"
             << i18nc("@title month and year", "%1 %2", hMon, hYear)
             << "</h2>" << endl;
@@ -190,7 +189,7 @@ void HtmlExport::createMonthView(QTextStream *ts)
         // Write table header
         *ts << "  <tr>";
         for (int i = 0; i < 7; ++i) {
-            *ts << "<th>" << KLocale::global()->calendar()->weekDayName(start.addDays(i)) << "</th>";
+            *ts << "<th>" << QLocale::system().dayName(start.addDays(i).dayOfWeek()) << "</th>";
         }
         *ts << "</tr>" << endl;
 
@@ -645,7 +644,7 @@ void HtmlExport::formatAttendees(QTextStream *ts,
 
 QString HtmlExport::breakString(const QString &text)
 {
-    int number = text.count(QLatin1String("\n"));
+    int number = text.count(QStringLiteral("\n"));
     if (number <= 0) {
         return text;
     } else {
@@ -708,15 +707,15 @@ QString cleanChars(const QString &text)
     txt = txt.replace(QLatin1Char('<'), QLatin1String("&lt;"));
     txt = txt.replace(QLatin1Char('>'), QLatin1String("&gt;"));
     txt = txt.replace(QLatin1Char('\"'), QLatin1String("&quot;"));
-    txt = txt.replace(QString::fromUtf8("ä"), QLatin1String("&auml;"));
-    txt = txt.replace(QString::fromUtf8("Ä"), QLatin1String("&Auml;"));
-    txt = txt.replace(QString::fromUtf8("ö"), QLatin1String("&ouml;"));
-    txt = txt.replace(QString::fromUtf8("Ö"), QLatin1String("&Ouml;"));
-    txt = txt.replace(QString::fromUtf8("ü"), QLatin1String("&uuml;"));
-    txt = txt.replace(QString::fromUtf8("Ü"), QLatin1String("&Uuml;"));
-    txt = txt.replace(QString::fromUtf8("ß"), QLatin1String("&szlig;"));
-    txt = txt.replace(QString::fromUtf8("€"), QLatin1String("&euro;"));
-    txt = txt.replace(QString::fromUtf8("é"), QLatin1String("&eacute;"));
+    txt = txt.replace(QStringLiteral("ä"), QLatin1String("&auml;"));
+    txt = txt.replace(QStringLiteral("Ä"), QLatin1String("&Auml;"));
+    txt = txt.replace(QStringLiteral("ö"), QLatin1String("&ouml;"));
+    txt = txt.replace(QStringLiteral("Ö"), QLatin1String("&Ouml;"));
+    txt = txt.replace(QStringLiteral("ü"), QLatin1String("&uuml;"));
+    txt = txt.replace(QStringLiteral("Ü"), QLatin1String("&Uuml;"));
+    txt = txt.replace(QStringLiteral("ß"), QLatin1String("&szlig;"));
+    txt = txt.replace(QStringLiteral("€"), QLatin1String("&euro;"));
+    txt = txt.replace(QStringLiteral("é"), QLatin1String("&eacute;"));
 
     return txt;
 }
